#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeAffinity(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeAffinity
                | 
                | Represents the hybrid shape affinity feature object.
                | Role: To access the data of the hybrid shape affinity feature object. This data
                | includes:
                | 
                |     The element to transform using the affinity
                |     The affinity reference coordinate system origin
                |     The affinity reference coordinate system reference plane
                |     The affinity reference coordinate system first direction
                |     The affinity ratio along the x, y and z directions of the reference
                |     coordinate system
                |     The element to transform using the affinity
                | 
                | The reference coordinate system is always a direct one.
                | 
                | LICENSING INFORMATION: Creation of volume result requires GSO
                | License
                | if GSO License is not granted , setting of Volume context has not
                | effect
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeAffinity
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_affinity = com_object

    @property
    def axis_first_direction(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AxisFirstDirection() As Reference
                | 
                |     Returns or sets the first direction of the reference coordinate
                |     system.
                |     Sub-element(s) supported (see Boundary object): RectilinearTriDimFeatEdge,
                |     RectilinearBiDimFeatEdge or RectilinearMonoDimFeatEdge.
                | 
                |     Example:
                |         This example retrieves in FirstDir the first direction of the reference
                |         coordinate system used by the Affinity hybrid shape
                |         feature.
                | 
                |          Dim FirstDir As Reference 
                |          Set FirstDir = Affinity.AxisFirstDirection

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_affinity.AxisFirstDirection)

    @axis_first_direction.setter
    def axis_first_direction(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_affinity.AxisFirstDirection = value.com_object

    @property
    def axis_origin(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AxisOrigin() As Reference
                | 
                |     Returns or sets the origin of the reference coordinate
                |     system.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in Origin the origin of the reference coordinate
                |         system used by the Affinity hybrid shape feature.
                | 
                |          Dim Origin As Reference 
                |          Set Origin = Affinity.AxisOrigin

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_affinity.AxisOrigin)

    @axis_origin.setter
    def axis_origin(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_affinity.AxisOrigin = value.com_object

    @property
    def axis_plane(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AxisPlane() As Reference
                | 
                |     Returns or sets the reference plane of the reference coordinate
                |     system.
                |     Sub-element(s) supported (see Boundary object):
                |     PlanarFace.
                | 
                |     Example:
                |         This example retrieves in RefPlane the reference plane of the reference
                |         coordinate system used by the Affinity hybrid shape
                |         feature.
                | 
                |          Dim RefPlane As Reference 
                |          Set RefPlane = Affinity.AxisPlane

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_affinity.AxisPlane)

    @axis_plane.setter
    def axis_plane(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_affinity.AxisPlane = value.com_object

    @property
    def creation_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CreationMode() As boolean
                | 
                |     Returns or sets the creation mode(creation or
                |     modification).
                |     Legal values: True if the result is a creation feature and False if the
                |     result is a modification feature.
                | 
                |     Example:
                | 
                |           This example sets that the mode of
                |          the hybShpAffinity hybrid shape affinity to creation
                |          
                | 
                |          hybShpAffinity.CreationMode = True

        :rtype: bool
        """

        return self.hybrid_shape_affinity.CreationMode

    @creation_mode.setter
    def creation_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_affinity.CreationMode = value

    @property
    def elem_to_transform(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ElemToTransform() As Reference
                | 
                |     Returns or sets the element to transform using the
                |     affinity.
                | 
                |     Example:
                |         This example retrieves in ElementToTransform the element to transform
                |         for the Affinity hybrid shape feature.
                | 
                |          Dim ElementToTransform As Reference 
                |          Set ElementToTransform = Affinity.ElemToTransform

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_affinity.ElemToTransform)

    @elem_to_transform.setter
    def elem_to_transform(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_affinity.ElemToTransform = value.com_object

    @property
    def volume_result(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VolumeResult() As boolean
                | 
                |     Returns or sets the volume result.
                |     Legal values: True if the result of affinity is required as volume (option
                |     is effective only in case of volumes,requires GSO License) and False if it is
                |     needed as surface .
                | 
                |     Example:
                | 
                |           This example sets that the result of
                |          the hybShpAffinity hybrid shape affinity is volume.
                |          
                | 
                |          hybShpAffinity.VolumeResult = True

        :rtype: bool
        """

        return self.hybrid_shape_affinity.VolumeResult

    @volume_result.setter
    def volume_result(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_affinity.VolumeResult = value

    @property
    def x_ratios(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property XRatios() As RealParam (Read Only)
                | 
                |     Returns the affinity ratio along the X Direction of the reference
                |     coordinate system.
                | 
                |     Example:
                |         This example retrieves in X the ratio of the affinity along the X
                |         Direction of the reference coordinate system used by the Affinity hybrid shape
                |         feature.
                | 
                |          Dim X As RealParam 
                |          Set X = Affinity.XRatios

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_affinity.XRatios)

    @property
    def y_ratios(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property YRatios() As RealParam (Read Only)
                | 
                |     Returns the affinity ratio along the Y Direction of the reference
                |     coordinate system.
                | 
                |     Example:
                |         This example retrieves in Y the ratio of the affinity along the Y
                |         Direction of the reference coordinate system used by the Affinity hybrid shape
                |         feature.
                | 
                |          Dim Y As RealParam 
                |          Set Y = Affinity.YRatios

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_affinity.YRatios)

    @property
    def z_ratios(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ZRatios() As RealParam (Read Only)
                | 
                |     Returns the affinity ratio along the Z Direction of the reference
                |     coordinate system.
                | 
                |     Example:
                |         This example retrieves in Z the ratio of the affinity along the Z
                |         Direction of the reference coordinate system used by the Affinity hybrid shape
                |         feature.
                | 
                |          Dim Z As RealParam 
                |          Set Z = Affinity.ZRatios

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_affinity.ZRatios)

    def __repr__(self):
        return f'HybridShapeAffinity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_setup_interfaces.tag import Tag
from pycatia.system_interfaces.collection import Collection


class TagGroup(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     TagGroup
                | 
                | Interface representing a TagGroup.
                | 
                | Role: This interface is used to work with TagGroup which consists of a list of
                | Tags.
                | The following code snippet can be used to obtain a TagGroup from a selected
                | Product
                | 
                |   Set ParentObject = CATIA.ActiveDocument.Selection.FindObject("CATIAProduct")	
                |   Set objTagGroup = ParentObject.GetTechnologicalObject("TagGroup")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Tag)
        self.tag_group = com_object

    def create_tag(self, io_tag: Tag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateTag(Tag ioTag)
                | 
                |     Creates a Tag
                | 
                |     Parameters:
                | 
                |         oTag
                |             Newly created Tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           Dim objTagGroup As TagGroup
                |           ...
                |           Dim objTag As Tag
                |           objTagGroup.CreateTag objTag

        :param Tag io_tag:
        :rtype: None
        """
        return self.tag_group.CreateTag(io_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_tag'
        # # vba_code = """
        # # Public Function create_tag(tag_group)
        # #     Dim ioTag (2)
        # #     tag_group.CreateTag ioTag
        # #     create_tag = ioTag
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_tag(self, i_tag: Tag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteTag(Tag iTag)
                | 
                |     Deletes a Tag
                | 
                |     Parameters:
                | 
                |         ioTag
                |             Tag to be deleted 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           Dim objTagGroup As TagGroup
                |           ...
                |           Dim objTag As Tag
                |           objTagGroup.DeleteTag objTag

        :param Tag i_tag:
        :rtype: None
        """
        return self.tag_group.DeleteTag(i_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_tag'
        # # vba_code = """
        # # Public Function delete_tag(tag_group)
        # #     Dim iTag (2)
        # #     tag_group.DeleteTag iTag
        # #     delete_tag = iTag
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_owner(self, io_parent_product: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOwner(CATBSTR ioParentProduct)
                | 
                |     Retrieves the name of the owner of this TagGroup.
                | 
                |     Parameters:
                | 
                |         ioParentProduct
                |             Name of the owner of this TagGroup. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           Dim objTagGroup As TagGroup
                |           ...
                |           Dim ownerName As String
                |           objTagGroup.GetOwner ownerName

        :param str io_parent_product:
        :rtype: None
        """
        return self.tag_group.GetOwner(io_parent_product)

    def get_tag(self, index: int) -> Tag:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTag(short index) As Tag
                | 
                |     Returns a Tag by Index.
                | 
                |     Parameters:
                | 
                |         index
                |             Index of the required Tag. 
                |         oTag
                |             Returned Tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           Dim objTagGroup As TagGroup
                |           ...
                |           For i = 1 To objTagGroup.Count
                |             Set objTag = objTagGroup.GetTag(i)
                |             ...
                |           Next

        :param int index:
        :rtype: Tag
        """
        return Tag(self.tag_group.GetTag(index))

    def get_tag_list(self, io_tag_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTagList(CATSafeArrayVariant ioTagList)
                | 
                |     Gets the List of names of Tags
                | 
                |     Parameters:
                | 
                |         ioTagList
                |             Underlying List of Tag names. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           Dim objTagGroup As TagGroup
                |           ...
                |           Dim List(100)
                |           objTagGroup.GetTagList List

        :param tuple io_tag_list:
        :rtype: None
        """
        return self.tag_group.GetTagList(io_tag_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tag_list'
        # # vba_code = """
        # # Public Function get_tag_list(tag_group)
        # #     Dim ioTagList (2)
        # #     tag_group.GetTagList ioTagList
        # #     get_tag_list = ioTagList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'TagGroup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class V4WritingSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         V4WritingSettingAtt
                | 
                | Represents the Saving As V4 Data setting controller object.
                | Role: The Saving As V4 Data setting controller object deals with the setting
                | parameters displayed in the Saving As V4 Data property page. To access this
                | property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of General to unfold the workbench list
                |     Click Compatibility
                | 
                | 
                | The different options for V4/V5SPEC tab:
                | The Writing Code Page
                | The Model Dimension
                | The Model Unit
                | The Initial Model File Path
                | The Associativity Mode
                | The Layer For Non Associative Data
                | The Error Feature Creation if the Save is not complete
                | The Curves Associated To Face Boundaries Creation
                | The V4 Model File Name In Capitals Letters
                | The Small Edges And Faces Cleaning Tolerance
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.v4_writing_setting_att = com_object

    @property
    def asso_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Asso_mode() As CATV4IV5V4AssociativityModeEnum
                | 
                |     Returns or sets the associativity mode of migration.
                |     Role: Returns or sets the associativity mode of migration.If non
                |     associative mode is chosen, it is possible to create or not the solid.

        :return: enum catv4_iv5_v4_associativity_mode_enum
        :rtype: int
        """

        return self.v4_writing_setting_att.Asso_mode

    @asso_mode.setter
    def asso_mode(self, value: int):
        """
        :param int value: enum catv4_iv5_v4_associativity_mode_enum
        """

        self.v4_writing_setting_att.Asso_mode = value

    @property
    def clean_tol_check(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CleanTolCheck() As boolean
                | 
                |     Returns or sets the small edges and faces cleaning tolerance
                |     activation.
                |     Role: Returns or sets the small edges and faces cleaning tolerance
                |     activation.

        :rtype: bool
        """

        return self.v4_writing_setting_att.CleanTolCheck

    @clean_tol_check.setter
    def clean_tol_check(self, value: bool):
        """
        :param bool value:
        """

        self.v4_writing_setting_att.CleanTolCheck = value

    @property
    def clean_tol_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CleanTolValue() As double
                | 
                |     Returns or sets the small edges and faces cleaning tolerance value if
                |     activated.
                |     Role: Returns or sets the small edges and faces cleaning tolerance value if
                |     activated.

        :rtype: float
        """

        return self.v4_writing_setting_att.CleanTolValue

    @clean_tol_value.setter
    def clean_tol_value(self, value: float):
        """
        :param float value:
        """

        self.v4_writing_setting_att.CleanTolValue = value

    @property
    def code_page_dest(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Code_page_Dest() As long
                | 
                |     Returns or sets the activation state of the writing code
                |     page.
                |     Role: Returns or sets the value of the writing code page.

        :rtype: int
        """

        return self.v4_writing_setting_att.Code_page_Dest

    @code_page_dest.setter
    def code_page_dest(self, value: int):
        """
        :param int value:
        """

        self.v4_writing_setting_att.Code_page_Dest = value

    @property
    def initial_model_file_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Initial_Model_File_Path() As CATBSTR
                | 
                |     Returns or sets the initial model file path.
                |     Role: Returns or sets the initial model file path.

        :rtype: str
        """

        return self.v4_writing_setting_att.Initial_Model_File_Path

    @initial_model_file_path.setter
    def initial_model_file_path(self, value: str):
        """
        :param str value:
        """

        self.v4_writing_setting_att.Initial_Model_File_Path = value

    @property
    def layer_for_no_asso(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Layer_for_No_Asso() As long
                | 
                |     Returns or sets the layer for not associative data.
                |     Role: Returns or sets the layer for not associative data.

        :rtype: int
        """

        return self.v4_writing_setting_att.Layer_for_No_Asso

    @layer_for_no_asso.setter
    def layer_for_no_asso(self, value: int):
        """
        :param int value:
        """

        self.v4_writing_setting_att.Layer_for_No_Asso = value

    @property
    def mode_create_display(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ModeCreateDisplay() As
                | CATV4IV5V4InternalCurveCreationEnum
                | 
                |     Returns or sets the curves associated to faces'boundaries creation
                |     option.
                |     Role: Returns or sets the curves associated to faces'boundaries creation
                |     option.

        :return: enum catv4_iv5_v4_internal_curve_creation_enum
        :rtype: int
        """

        return self.v4_writing_setting_att.ModeCreateDisplay

    @mode_create_display.setter
    def mode_create_display(self, value: int):
        """
        :param int value: enum catv4_iv5_v4_internal_curve_creation_enum
        """

        self.v4_writing_setting_att.ModeCreateDisplay = value

    @property
    def mode_error_display(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ModeErrorDisplay() As
                | CATV4IV5V4ErrorFeatureCreationEnum
                | 
                |     Returns or sets the error feature creation option.
                |     Role: Returns or sets the error feature creation option.

        :return: enum catv4_iv5_v4_error_feature_creation_enum
        :rtype: int
        """

        return self.v4_writing_setting_att.ModeErrorDisplay

    @mode_error_display.setter
    def mode_error_display(self, value: int):
        """
        :param int value: enum catv4_iv5_v4_error_feature_creation_enum
        """

        self.v4_writing_setting_att.ModeErrorDisplay = value

    @property
    def model_dimension(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Model_Dimension() As double
                | 
                |     Returns or sets the model dimension.
                |     Role: Returns or sets the model dimension.

        :rtype: float
        """

        return self.v4_writing_setting_att.Model_Dimension

    @model_dimension.setter
    def model_dimension(self, value: float):
        """
        :param float value:
        """

        self.v4_writing_setting_att.Model_Dimension = value

    @property
    def model_factor(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Model_Factor() As double
                | 
                |     Returns or sets the model factor.
                |     Role: Returns or sets the model factor that manages the conversion of model
                |     dimension in millimeters.

        :rtype: float
        """

        return self.v4_writing_setting_att.Model_Factor

    @model_factor.setter
    def model_factor(self, value: float):
        """
        :param float value:
        """

        self.v4_writing_setting_att.Model_Factor = value

    @property
    def model_file_name(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Model_File_Name() As boolean
                | 
                |     Returns or sets the model file name in capital letters
                |     option.
                |     Role: Returns or sets the model file name in capital letters option.

        :rtype: bool
        """

        return self.v4_writing_setting_att.Model_File_Name

    @model_file_name.setter
    def model_file_name(self, value: bool):
        """
        :param bool value:
        """

        self.v4_writing_setting_att.Model_File_Name = value

    @property
    def model_unit(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Model_Unit() As long
                | 
                |     Returns or sets the model unit.
                |     Role: Returns or sets the model unit.

        :rtype: int
        """

        return self.v4_writing_setting_att.Model_Unit

    @model_unit.setter
    def model_unit(self, value: int):
        """
        :param int value:
        """

        self.v4_writing_setting_att.Model_Unit = value

    def get_asso_mode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAsso_modeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Asso_mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetAsso_modeInfo(admin_level, o_locked)

    def get_clean_tol_check_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCleanTolCheckInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the CleanTolCheck setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetCleanTolCheckInfo(admin_level, o_locked)

    def get_clean_tol_value_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCleanTolValueInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the CleanTolValue setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetCleanTolValueInfo(admin_level, o_locked)

    def get_code_page_dest_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCode_page_DestInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Code_page_Dest setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetCode_page_DestInfo(admin_level, o_locked)

    def get_initial_model_file_path_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetInitial_Model_File_PathInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Initial_Model_File_Path setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetInitial_Model_File_PathInfo(admin_level, o_locked)

    def get_layer_for_no_asso_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLayer_for_No_AssoInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Layer_for_No_Asso setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetLayer_for_No_AssoInfo(admin_level, o_locked)

    def get_mode_create_display_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetModeCreateDisplayInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the ModeCreateDisplay setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetModeCreateDisplayInfo(admin_level, o_locked)

    def get_mode_error_display_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetModeErrorDisplayInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the ModeErrorDisplay setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetModeErrorDisplayInfo(admin_level, o_locked)

    def get_model_dimension_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetModel_DimensionInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Model_Dimension setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetModel_DimensionInfo(admin_level, o_locked)

    def get_model_factor_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetModel_FactorInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Model_Factor setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetModel_FactorInfo(admin_level, o_locked)

    def get_model_file_name_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetModel_File_NameInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Model_File_Name setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetModel_File_NameInfo(admin_level, o_locked)

    def get_model_unit_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetModel_UnitInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Model_Unit setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_writing_setting_att.GetModel_UnitInfo(admin_level, o_locked)

    def set_asso_mode_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAsso_modeLock(boolean iLock)
                | 
                |     Locks or unlocks the Asso_mode setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetAsso_modeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_asso_mode_lock'
        # # vba_code = """
        # # Public Function set_asso_mode_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetAsso_modeLock iLock
        # #     set_asso_mode_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_clean_tol_check_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCleanTolCheckLock(boolean iLock)
                | 
                |     Locks or unlocks the CleanTolCheck setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetCleanTolCheckLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_clean_tol_check_lock'
        # # vba_code = """
        # # Public Function set_clean_tol_check_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetCleanTolCheckLock iLock
        # #     set_clean_tol_check_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_clean_tol_value_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCleanTolValueLock(boolean iLock)
                | 
                |     Locks or unlocks the CleanTolValue setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetCleanTolValueLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_clean_tol_value_lock'
        # # vba_code = """
        # # Public Function set_clean_tol_value_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetCleanTolValueLock iLock
        # #     set_clean_tol_value_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_code_page_dest_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCode_page_DestLock(boolean iLock)
                | 
                |     Locks or unlocks the Code_page_Dest setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetCode_page_DestLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_code_page_dest_lock'
        # # vba_code = """
        # # Public Function set_code_page_dest_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetCode_page_DestLock iLock
        # #     set_code_page_dest_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_initial_model_file_path_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetInitial_Model_File_PathLock(boolean iLock)
                | 
                |     Locks or unlocks the Initial_Model_File_Path setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetInitial_Model_File_PathLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_initial_model_file_path_lock'
        # # vba_code = """
        # # Public Function set_initial_model_file_path_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetInitial_Model_File_PathLock iLock
        # #     set_initial_model_file_path_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_layer_for_no_asso_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLayer_for_No_AssoLock(boolean iLock)
                | 
                |     Locks or unlocks the Layer_for_No_Asso setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetLayer_for_No_AssoLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_layer_for_no_asso_lock'
        # # vba_code = """
        # # Public Function set_layer_for_no_asso_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetLayer_for_No_AssoLock iLock
        # #     set_layer_for_no_asso_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mode_create_display_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetModeCreateDisplayLock(boolean iLock)
                | 
                |     Locks or unlocks the ModeCreateDisplay setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetModeCreateDisplayLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mode_create_display_lock'
        # # vba_code = """
        # # Public Function set_mode_create_display_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetModeCreateDisplayLock iLock
        # #     set_mode_create_display_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mode_error_display_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetModeErrorDisplayLock(boolean iLock)
                | 
                |     Locks or unlocks the ModeErrorDisplay setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetModeErrorDisplayLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mode_error_display_lock'
        # # vba_code = """
        # # Public Function set_mode_error_display_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetModeErrorDisplayLock iLock
        # #     set_mode_error_display_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_model_dimension_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetModel_DimensionLock(boolean iLock)
                | 
                |     Locks or unlocks the Model_Dimension setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetModel_DimensionLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_model_dimension_lock'
        # # vba_code = """
        # # Public Function set_model_dimension_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetModel_DimensionLock iLock
        # #     set_model_dimension_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_model_factor_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetModel_FactorLock(boolean iLock)
                | 
                |     Locks or unlocks the Model_Factor setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetModel_FactorLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_model_factor_lock'
        # # vba_code = """
        # # Public Function set_model_factor_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetModel_FactorLock iLock
        # #     set_model_factor_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_model_file_name_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetModel_File_NameLock(boolean iLock)
                | 
                |     Locks or unlocks the Model_File_Name setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetModel_File_NameLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_model_file_name_lock'
        # # vba_code = """
        # # Public Function set_model_file_name_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetModel_File_NameLock iLock
        # #     set_model_file_name_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_model_unit_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetModel_UnitLock(boolean iLock)
                | 
                |     Locks or unlocks the Model_Unit setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_writing_setting_att.SetModel_UnitLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_model_unit_lock'
        # # vba_code = """
        # # Public Function set_model_unit_lock(v4_writing_setting_att)
        # #     Dim iLock (2)
        # #     v4_writing_setting_att.SetModel_UnitLock iLock
        # #     set_model_unit_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'V4WritingSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class ManipSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         ManipSettingAtt
                | 
                | Interface to handle parameters of DMU Manip Tools Options Tab page Role: This
                | interface is implemented by a component which represents the controller of DMU
                | Manip Tools Options parameter settings.
                | 
                |     Methods to set value of each parameter
                |     Methods to get value of each parameter
                |     Methods to get information on each parameter
                |     Methods to lock/unlock value of each parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manip_setting_att = com_object

    def get_angle_step_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAngleStepInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AngleStep
                |     parameter.
                |     Role:Retrieves the state of the AngleStep parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetAngleStepInfo(io_admin_level, io_locked)

    def get_clash_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetClashModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ClashMode
                |     parameter.
                |     Role:Retrieves the state of the ClashMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetClashModeInfo(io_admin_level, io_locked)

    def get_clash_sound_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetClashSoundInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ClashSound
                |     parameter.
                |     Role:Retrieves the state of the ClashSound parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetClashSoundInfo(io_admin_level, io_locked)

    def get_distance_step_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDistanceStepInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DistanceStep
                |     parameter.
                |     Role:Retrieves the state of the DistanceStep parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetDistanceStepInfo(io_admin_level, io_locked)

    def get_manip_auto_insert_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetManipAutoInsertInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ManipAutoInsert
                |     parameter.
                |     Role:Retrieves the state of the ManipAutoInsert parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetManipAutoInsertInfo(io_admin_level, io_locked)

    def get_record_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRecordModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RecordMode
                |     parameter.
                |     Role:Retrieves the state of the RecordMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetRecordModeInfo(io_admin_level, io_locked)

    def get_snap_angle_distance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSnapAngleDistanceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SnapAngleDistance
                |     parameter.
                |     Role:Retrieves the state of the SnapAngleDistance parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetSnapAngleDistanceInfo(io_admin_level, io_locked)

    def get_snap_position_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSnapPositionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SnapPosition
                |     parameter.
                |     Role:Retrieves the state of the SnapPosition parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.manip_setting_att.GetSnapPositionInfo(io_admin_level, io_locked)

    def set_angle_step_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAngleStepLock(boolean iLocked)
                | 
                |     Locks or unlocks the AngleStep parameter.
                |     Role:Locks or unlocks the DistanceStep parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetAngleStepLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_angle_step_lock'
        # # vba_code = """
        # # Public Function set_angle_step_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetAngleStepLock iLocked
        # #     set_angle_step_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_clash_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetClashModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ClashMode parameter.
                |     Role:Locks or unlocks the ClashMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         S_OK : if the ManipAutoInsert value was correctly obtained
                |         E_FAIL : if the ManipAutoInsert value was not correctly obtained

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetClashModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_clash_mode_lock'
        # # vba_code = """
        # # Public Function set_clash_mode_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetClashModeLock iLocked
        # #     set_clash_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_clash_sound_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetClashSoundLock(boolean iLocked)
                | 
                |     Locks or unlocks the ClashSound parameter.
                |     Role:Locks or unlocks the ClashSound parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         S_OK : if the RecordMode value was correctly obtained
                |         E_FAIL : if the RecordMode value was not correctly obtained

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetClashSoundLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_clash_sound_lock'
        # # vba_code = """
        # # Public Function set_clash_sound_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetClashSoundLock iLocked
        # #     set_clash_sound_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_distance_step_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDistanceStepLock(boolean iLocked)
                | 
                |     Locks or unlocks the DistanceStep parameter.
                |     Role:Locks or unlocks the DistanceStep parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetDistanceStepLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_distance_step_lock'
        # # vba_code = """
        # # Public Function set_distance_step_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetDistanceStepLock iLocked
        # #     set_distance_step_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_manip_auto_insert_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetManipAutoInsertLock(boolean iLocked)
                | 
                |     Locks or unlocks the ManipAutoInsert parameter.
                |     Role:Locks or unlocks the ManipAutoInsert parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetManipAutoInsertLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_manip_auto_insert_lock'
        # # vba_code = """
        # # Public Function set_manip_auto_insert_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetManipAutoInsertLock iLocked
        # #     set_manip_auto_insert_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_record_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRecordModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the RecordMode parameter.
                |     Role:Locks or unlocks the RecordMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetRecordModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_record_mode_lock'
        # # vba_code = """
        # # Public Function set_record_mode_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetRecordModeLock iLocked
        # #     set_record_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_snap_angle_distance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSnapAngleDistanceLock(boolean iLocked)
                | 
                |     Locks or unlocks the SnapAngleDistance parameter.
                |     Role:Locks or unlocks the SnapAngleDistance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetSnapAngleDistanceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_snap_angle_distance_lock'
        # # vba_code = """
        # # Public Function set_snap_angle_distance_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetSnapAngleDistanceLock iLocked
        # #     set_snap_angle_distance_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_snap_position_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSnapPositionLock(boolean iLocked)
                | 
                |     Locks or unlocks the SnapPosition parameter.
                |     Role:Locks or unlocks the SnapPosition parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.manip_setting_att.SetSnapPositionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_snap_position_lock'
        # # vba_code = """
        # # Public Function set_snap_position_lock(manip_setting_att)
        # #     Dim iLocked (2)
        # #     manip_setting_att.SetSnapPositionLock iLocked
        # #     set_snap_position_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ManipSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_interfaces.drawing_dim_ext_line import DrawingDimExtLine
from pycatia.drafting_interfaces.drawing_dim_line import DrawingDimLine
from pycatia.drafting_interfaces.drawing_dim_value import DrawingDimValue
from pycatia.knowledge_interfaces.parameters import Parameters
from pycatia.system_interfaces.any_object import AnyObject


class DrawingDimension(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingDimension
                | 
                | Represents a drawing dimension in a Drawing view.
                | 
                | Returns sub parts of dimension: Extension lines, dimension line and dimension
                | value.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_dimension = com_object

    @property
    def cumulate_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property CumulateMode() As boolean (Read Only)
                | 
                |     Returns cumulate mode or not.
                | 
                |     Example:
                |         This example retrieves cumulate mode or not MyDimension drawing
                |         dimension.
                | 
                |          oCumulateMode = MyDimension.CumulateMode

        :rtype: bool
        """

        return self.drawing_dimension.CumulateMode

    @property
    def dim_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DimStatus() As CatDimAnalyse (Read Only)
                | 
                |     Returns or sets status of dimension.
                | 
                |     Example:
                |         This example retrieves status of dimension MyDimension drawing
                |         dimension.
                | 
                |          oIsStatus = MyDimension.DimStatus

        :return: enum cat_dim_analyse
        :rtype: int
        """

        return self.drawing_dimension.DimStatus

    @property
    def dim_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DimType() As CatDimType (Read Only)
                | 
                |     Returns dimension type.
                | 
                |     Example:
                |         This example retrieves the dimension type MyDimension drawing
                |         dimension.
                | 
                |          oTypeDim = MyDimension.DimType

        :return: enum cat_dim_type
        :rtype: int
        """

        return self.drawing_dimension.DimType

    @property
    def dual_value(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DualValue() As CatDimDualDisplay
                | 
                |     Returns or sets dual value type of dimension value.
                | 
                |     Example:
                |         This example retrieves dual value type of dimension value MyDimension
                |         drawing dimension.
                | 
                |          oDualValue = MyDimension.DualValue

        :return: enum cat_dim_dual_display
        :rtype: int
        """

        return self.drawing_dimension.DualValue

    @dual_value.setter
    def dual_value(self, value: int):
        """
        :param int value: enum cat_dim_dual_display
        """

        self.drawing_dimension.DualValue = value

    @property
    def forshortened(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Forshortened() As boolean
                | 
                |     Returns or sets foreshortened mode or not.
                | 
                |     Example:
                |         This example retrieves foreshortened mode or not MyDimension drawing
                |         dimension.
                | 
                |          oForsh = MyDimension.Forshortened

        :rtype: bool
        """

        return self.drawing_dimension.Forshortened

    @forshortened.setter
    def forshortened(self, value: bool):
        """
        :param bool value:
        """

        self.drawing_dimension.Forshortened = value

    @property
    def half_dim_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property HalfDimMode() As boolean
                | 
                |     Returns or sets half dimension mode or not.
                | 
                |     Example:
                |         This example retrieves half dimension mode or not MyDimension drawing
                |         dimension.
                | 
                |          oHalfDimMode = MyDimension.HalfDimMode

        :rtype: bool
        """

        return self.drawing_dimension.HalfDimMode

    @half_dim_mode.setter
    def half_dim_mode(self, value: bool):
        """
        :param bool value:
        """

        self.drawing_dimension.HalfDimMode = value

    @property
    def is_clipped(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property IsClipped() As boolean (Read Only)
                | 
                |     Returns the clipping status of the dimension. Returns TRUE if the dimension
                |     si clipped 
                | Example:
                |     This example gets clipping status of MyDimension path.
                | 
                |      myDimensionClippingStatus=MyDimension.IsClipped

        :rtype: bool
        """

        return self.drawing_dimension.IsClipped

    @property
    def nb_ext_line(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property NbExtLine() As long (Read Only)
                | 
                |     Returns numbers of extension line of dimension.
                | 
                |     Example:
                |         This example retrieves numbers of extension line of dimension
                |         MyDimension drawing dimension.
                | 
                |          oNbExtline = MyDimension.NbExtLine

        :rtype: int
        """

        return self.drawing_dimension.NbExtLine

    @property
    def nb_symb(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property NbSymb() As long (Read Only)
                | 
                |     Returns numbers of symbol of dimension.
                | 
                |     Example:
                |         This example retrieves numbers of symbol of dimension MyDimension
                |         drawing dimension.
                | 
                |          oNbSymb = MyDimension.NbSymb

        :rtype: int
        """

        return self.drawing_dimension.NbSymb

    @property
    def parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Parameters() As Parameters (Read Only)
                | 
                |     Returns the collection of parameters of the dimension.
                |     Warning: The returned parameters collection does not support adding
                |     parameters, it is mainly provided to access dimension
                |     value.
                | 
                |     Example:
                | 
                |           This example retrieves in DimensionParameters the collection
                |           of
                |          parameters currently managed by a dimension.
                |          
                | 
                |          Dim DimensionParameters As Parameters
                |          Set DimensionParameters = MyDimension.Parameters
                |          Dim DimValueParameter As Parameter
                |          Set DimValueParameter = DimensionParameters.Item("Measured length")

        :rtype: Parameters
        """

        return Parameters(self.drawing_dimension.Parameters)

    @property
    def symbols_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property SymbolsSide() As long
                | 
                |     Returns or sets symbol side of dimension line. Legal values: 0 : Automatic positioning (Inside or
                |     Outside). 1 : Symbols are inside. 2 : Symbols are outside. 3 : First symbol inside , second symbol
                |     outside. 4 : First symbol outside, second symbol inside.
                | 
                |     Example:
                |         This example retrieves symbol side of dimension line MyDimension
                |         drawing dimension.
                | 
                |          oSymbSide = MyDimension.SymbolsSide

        :rtype: int
        """

        return self.drawing_dimension.SymbolsSide

    @symbols_side.setter
    def symbols_side(self, value: int):
        """
        :param int value:
        """

        self.drawing_dimension.SymbolsSide = value

    @property
    def true_dim_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property TrueDimMode() As boolean (Read Only)
                | 
                |     Returns or sets true dimension mode or not.
                | 
                |     Example:
                |         This example retrieves true dimension mode or not MyDimension drawing
                |         dimension.
                | 
                |          oTrueDimMode = MyDimension.TrueDimMode

        :return: bool
        """

        return self.drawing_dimension.TrueDimMode

    @property
    def value_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueAngle() As double
                | 
                |     Returns or sets angle of dimension value.
                | 
                |     Example:
                |         This example retrieves angle of dimension value MyDimension drawing
                |         dimension.
                | 
                |          oValueAng = MyDimension.ValueAngle

        :rtype: float
        """

        return self.drawing_dimension.ValueAngle

    @value_angle.setter
    def value_angle(self, value: float):
        """
        :param float value:
        """

        self.drawing_dimension.ValueAngle = value

    @property
    def value_auto_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueAutoMode() As long
                | 
                |     Returns or sets auto mode of dimension value or not.
                | 
                |     Example:
                |         This example retrieves auto mode of dimension value or not MyDimension
                |         drawing dimension.
                | 
                |          oValueAutoMode = MyDimension.ValueAutoMode

        :rtype: int
        """

        return self.drawing_dimension.ValueAutoMode

    @value_auto_mode.setter
    def value_auto_mode(self, value: int):
        """
        :param int value:
        """

        self.drawing_dimension.ValueAutoMode = value

    @property
    def value_display(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueDisplay() As long
                | 
                |     Returns or sets display of dimension value state.
                | 
                |     Example:
                |         This example retrieves display of dimension value state MyDimension
                |         drawing dimension.
                | 
                |          oValueDisplay = MyDimension.ValueDisplay

        :rtype: int
        """

        return self.drawing_dimension.ValueDisplay

    @value_display.setter
    def value_display(self, value: int):
        """
        :param int value:
        """

        self.drawing_dimension.ValueDisplay = value

    @property
    def value_frame(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueFrame() As CatDimFrame
                | 
                |     Returns or sets frame type of dimension value.
                | 
                |     Example:
                |         This example retrieves frame type of dimension value MyDimension
                |         drawing dimension.
                | 
                |          oValueFrame = MyDimension.ValueFrame

        :return: enum cat_dim_frame
        :rtype: int
        """

        return self.drawing_dimension.ValueFrame

    @value_frame.setter
    def value_frame(self, value: int):
        """
        :param int value: enum cat_dim_frame
        """

        self.drawing_dimension.ValueFrame = value

    @property
    def value_in_out(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueInOut() As long
                | 
                |     Returns or sets in/out mode of dimension value or not.
                | 
                |     Example:
                |         This example retrieves in/out mode of dimension value or not
                |         MyDimension drawing dimension.
                | 
                |          oInOut = MyDimension.ValueInOut

        :rtype: int
        """

        return self.drawing_dimension.ValueInOut

    @value_in_out.setter
    def value_in_out(self, value: int):
        """
        :param int value:
        """

        self.drawing_dimension.ValueInOut = value

    @property
    def value_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueOrientation() As CatDimOrientation
                | 
                |     Returns or sets orientation of dimension value.
                | 
                |     Example:
                |         This example retrieves orientation of dimension value MyDimension
                |         drawing dimension.
                | 
                |          oValueOrient = MyDimension.ValueOrientation

        :return: enum cat_dim_orientation
        :rtype: int
        """

        return self.drawing_dimension.ValueOrientation

    @value_orientation.setter
    def value_orientation(self, value: int):
        """
        :param int value: enum cat_dim_orientation
        """

        self.drawing_dimension.ValueOrientation = value

    @property
    def value_reference(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueReference() As CatDimReference
                | 
                |     Returns or sets reference of dimension value.
                | 
                |     Example:
                |         This example retrieves reference of dimension value MyDimension drawing
                |         dimension.
                | 
                |          oValueRef = MyDimension.ValueReference

        :return: enum cat_dim_reference
        :rtype: int
        """

        return self.drawing_dimension.ValueReference

    @value_reference.setter
    def value_reference(self, value: int):
        """
        :param int value: enum cat_dim_reference
        """

        self.drawing_dimension.ValueReference = value

    def get_boundary_box(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetBoundaryBox(CATSafeArrayVariant oValues)
                | 
                |     Get boundary box coordinates of dimension value.
                | 
                |     Parameters:
                | 
                |         oValues
                |             List of boundary box coordinates (X1,Y1,X2,Y2,.....X4,Y4).
                |             
                |         Example:
                |             This example gets boundary box coordinates of MyDimension
                |             path.
                | 
                |              MyDimension.GetBoundaryBox(oValues)

        :rtype: tuple
        """
        return self.drawing_dimension.GetBoundaryBox()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_boundary_box'
        # # vba_code = """
        # # Public Function get_boundary_box(drawing_dimension)
        # #     Dim oValues (2)
        # #     drawing_dimension.GetBoundaryBox oValues
        # #     get_boundary_box = oValues
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_clip(self) -> tuple[float, float, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetClip(double X,
                | double Y,
                | long oKeptSide)
                | 
                |     Gets informations of the dimension clipping. The value of this parameter
                |     can be 1 or 2, and the kept side will be the one corresponding respectively to
                |     ptldc1 and ptldc2 from GetGeomInfo method defined in CATIADrawingDimensionLine
                |     idl interface. interface. If iKeptSide==0, there is no dimension
                |     clipping.
                | 
                |     Parameters:
                | 
                |         oX
                |             X coordinate of position. 
                |         oY
                |             Y coordinate of position. 
                |         oKeptSide
                |             returns the part of the dimension line will be clipped.
                |             
                |         Example:
                | 
                |              if MyDimension.IsClipped then
                |                MyDimension.GetClip(X, Y, keptSide)
                |              end if

        :return: tuple[float, float, int]
        :rtype: tuple
        """
        return self.drawing_dimension.GetClip()

    def get_dim_ext_line(self) -> DrawingDimExtLine:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDimExtLine() As DrawingDimExtLine
                | 
                |     Returns the drawing extension line of the drawing
                |     dimension.
                | 
                |     Example:
                |         This example retrieves in DimExtLine extension line of the MyDimension
                |         drawing dimension.
                | 
                |          Dim DimExtLine As DrawingDimExtLine
                |          Set DimExtLine = MyDimension.GetDimExtLine
                |          
                | 
                |     See also:
                |         DrawingDimLine

        :rtype: DrawingDimExtLine
        """
        return DrawingDimExtLine(self.drawing_dimension.GetDimExtLine())

    def get_dim_line(self) -> DrawingDimLine:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDimLine() As DrawingDimLine
                | 
                |     Returns the drawing dimension line of the drawing
                |     dimension.
                | 
                |     Example:
                |         This example retrieves in DimDimLine dimension line of the MyDimension
                |         drawing dimension.
                | 
                |          Dim DimDimLine As DrawingDimLine
                |          Set DimDimLine = MyDimension.GetDimLine
                |          
                | 
                |     See also:
                |         DrawingDimLine

        :rtype: DrawingDimLine
        """
        return DrawingDimLine(self.drawing_dimension.GetDimLine())

    def get_tolerances(self) -> tuple[int, str, str, str, float, float, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetTolerances(long oTolType,
                | CATBSTR oTolName,
                | CATBSTR oUpTol,
                | CATBSTR oLowTol,
                | double odUpTol,
                | double odLowTol,
                | long oDisplayMode)
                | 
                |     Get tolerance information of dimension value.
                | 
                |     Parameters:
                | 
                |         oTolType
                |             Tolerance type 
                |         oTolName
                |             Tolerance name 
                |         oUpTol
                |             Upper tolerance value (alpha numerical type) 
                |         oLowTol
                |             Lower tolerance value (alpha numerical type) 
                |         odUpTol
                |             Upper tolerance value (numerical type) 
                |         odLowTol
                |             Lower tolerance value (numerical type) 
                |         oDisplayMode
                |             Tolerance display mode 
                |         Example:
                |             This example gets tolerance information of MyDimension
                |             path.
                | 
                |              MyDimension.GetTolerances(oTolType, oTolName, oUpTol, oLowTol,
                |              odUpTol, odLowTol, oDisplayMode)

        :return: tuple(int, str, str, str, float, float, int)
        :rtype: tuple
        """
        return self.drawing_dimension.GetTolerances()

    def get_value(self) -> DrawingDimValue:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetValue() As DrawingDimValue
                | 
                |     Returns the drawing value of the drawing dimension.
                | 
                |     Example:
                |         This example retrieves in DimDimValue value of the MyDimension drawing
                |         dimension.
                | 
                |          Dim DimDimValue As DrawingDimValue
                |          Set DimDimValue = MyDimension.GetValue
                |          
                | 
                |     See also:
                |         DrawingDimValue

        :rtype: DrawingDimValue
        """
        return DrawingDimValue(self.drawing_dimension.GetValue())

    def move_value(self, x: float, y: float, sub_part: int, dim_angle_behavior: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub MoveValue(double X,
                | double Y,
                | long SubPart,
                | long DimAngleBehavior)
                | 
                |     Move dimension value.
                | 
                |     Parameters:
                | 
                |         X
                |             X coordinate of position. 
                |         Y
                |             Y coordinate of position. 
                |         SubPart
                |             Defines which part of the dimension should be
                |             moved.
                |             -1 = Value (vertical move is take account according ptPos coordinates)
                |             0 = Both dimension line and value
                |             1 = Value
                |             2 = Dimension line
                |             3 = Secondary part
                |             4 = Secondary part and value
                |             5 = Secondary part and dimension line
                |             6 = Secondary part, dimension line and value
                |             7 = Value leader (for dimension line with leader one part or two parts) 
                |         DimAngleBehavior
                |             Defines angle dimension line behavior.
                |             0 = Sector angle is switched when ptPos is in opposite sector (Default)
                |             1 = Sector angle is kept what ever ptPos placement 
                |         Example:
                |             This example move dimension value MyDimension
                |             path.
                | 
                |              MyDimension.MoveValue(X, Y, SubPart,
                |              DimAngleBehavior)

        :param float x:
        :param float y:
        :param int sub_part:
        :param int dim_angle_behavior:
        :rtype: None
        """
        return self.drawing_dimension.MoveValue(x, y, sub_part, dim_angle_behavior)

    def restore_value_position(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RestoreValuePosition()
                | 
                |     Restore dimension value position. 
                | Example:
                |     This example gets Restore dimension value position of MyDimension
                |     path.
                | 
                |      MyDimension.RestoreValuePosition()

        :rtype: None
        """
        return self.drawing_dimension.RestoreValuePosition()

    def set_clip(self, x: float, y: float, i_kept_side: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetClip(double X,
                | double Y,
                | long iKeptSide)
                | 
                |     Creates a clip on the dimension at the given point, with respect to the
                |     side given by iKeptSide. The value of this parameter can be 1 or 2, and the
                |     kept side will be the one corresponding respectively to ptldc1 and ptldc2 from
                |     GetGeomInfo method defined in CATIADrawingDimensionLine idl interface.
                |     interface.
                | 
                |     Parameters:
                | 
                |         iX
                |             X coordinate of position. 
                |         iY
                |             Y coordinate of position. 
                |         iKeptSide
                |             Defines which part of the dimension should be kept.
                |             
                |         Example:
                |             This example clips dimension MyDimension path.
                | 
                |              MyDimension.SetClip(X, Y, 1)

        :param float x:
        :param float y:
        :param int i_kept_side:
        :rtype: None
        """
        return self.drawing_dimension.SetClip(x, y, i_kept_side)

    def set_tolerances(self,
                       i_tol_type: int,
                       itol_name: str,
                       i_up_tol: str,
                       i_low_tol: str,
                       id_up_tol: float,
                       id_low_tol: float,
                       display_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetTolerances(long iTolType,
                | CATBSTR itolName,
                | CATBSTR iUpTol,
                | CATBSTR iLowTol,
                | double idUpTol,
                | double idLowTol,
                | long DisplayMode)
                | 
                |     Set tolerance information of dimension value.
                | 
                |     Parameters:
                | 
                |         iTolType
                |             Tolerance type 
                |         itolName
                |             Tolerance name 
                |         iUpTol
                |             Upper tolerance value (alpha numerical type) 
                |         iLowTol
                |             Lower tolerance value (alpha numerical type) 
                |         idUpTol
                |             Upper tolerance value (numerical type) 
                |         idLowTol
                |             Lower tolerance value (numerical type) 
                |         DisplayMode
                |             Tolerance display mode 
                |         Example:
                |             This example sets tolerance information of MyDimension
                |             path.
                | 
                |              MyDimension.SetTolerances(iTolType, itolName, iUpTol, iLowTol,
                |              idUpTol, idLowTol, DisplayMode)

        :param int i_tol_type:
        :param str itol_name:
        :param str i_up_tol:
        :param str i_low_tol:
        :param float id_up_tol:
        :param float id_low_tol:
        :param int display_mode:
        :rtype: None
        """
        return self.drawing_dimension.SetTolerances(
            i_tol_type,
            itol_name,
            i_up_tol,
            i_low_tol,
            id_up_tol,
            id_low_tol,
            display_mode
        )

    def unclip(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Unclip()
                | 
                |     Unclip the dimension if it is clipped. 
                | Example:
                |     This example unclip MyDimension path.
                | 
                |      if MyDimension.IsClipped then
                |        MyDimension.Unclip

        :rtype: None
        """
        return self.drawing_dimension.Unclip()

    def __repr__(self):
        return f'DrawingDimension(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_anthro_variable import SWKAnthroVariable
from pycatia.dnb_human_modeling_interfaces.swk_manikin_part import SWKManikinPart


class SWKAnthro(SWKManikinPart):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKManikinPart
                |                         SWKAnthro
                | 
                | This interface manages the anthropometry of the manikin.
                | It provides access to the anthropometry data (variables,
                | sex...)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_anthro = com_object

    @property
    def construction_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConstructionType() As CATBSTR
                | 
                |     Return or sets the construction type of the manikin. This property can take
                |     the following two values: "Standing" and "Sitting".
                |     If the construction is set to "Standing",
                |     then the manikin is constructed as of type 'standing'.
                |     If the construction is set to "Sitting",
                |     then the manikin is constructed as of type 'sitting'.
                | 
                |     The chosen construction type influences the way the manikin's hips,
                |     thighs and knees are constructed to reflect the changes in those body
                |     parts when a human changes from a standing to a sitting posture.

        :rtype: str
        """

        return self.swk_anthro.ConstructionType

    @construction_type.setter
    def construction_type(self, value: str):
        """
        :param str value:
        """

        self.swk_anthro.ConstructionType = value

    @property
    def gender(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Gender() As CATBSTR
                | 
                |     Returns or sets the gender of the manikin.

        :rtype: str
        """

        return self.swk_anthro.Gender

    @gender.setter
    def gender(self, value: str):
        """
        :param str value:
        """

        self.swk_anthro.Gender = value

    @property
    def interpolation_method(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InterpolationMethod() As CATBSTR
                | 
                |     Returns or sets the interpolation. The interpolation is an
                |     algorithm
                |     that restricts the values entered by the user to a certain minimum and
                |     maximum value. Valid values are "None" or "Multinormal".

        :rtype: str
        """

        return self.swk_anthro.InterpolationMethod

    @interpolation_method.setter
    def interpolation_method(self, value: str):
        """
        :param str value:
        """

        self.swk_anthro.InterpolationMethod = value

    @property
    def limit_bound(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LimitBound() As double
                | 
                |     Returns or sets the population accommodation, in terms of a limit
                |     bound.
                |     The population accommodation is used in the multi-normal
                |     algorithm, to calculate the limits of the automatic
                |     variables
                |     when a user-defined anthropometry is entered.
                |     The greater the population accommodation is, the wider the limits
                |     on the automatic variables will be. The value of this property must le
                |     within the range [0.0, 4.0].

        :rtype: float
        """

        return self.swk_anthro.LimitBound

    @limit_bound.setter
    def limit_bound(self, value: float):
        """
        :param float value:
        """

        self.swk_anthro.LimitBound = value

    @property
    def number_of_variables(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfVariables() As long (Read Only)
                | 
                |     Returns the number of variables contained in this anthropometry.

        :rtype: int
        """

        return self.swk_anthro.NumberOfVariables

    @property
    def population(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Population() As CATBSTR
                | 
                |     Return or sets the Population of the manikin. The population provided must
                |     be one of the default populations ("American", "Canadian", "French",
                |     "Japanese", "Korean", "German" or "Chinese (Taiwan)"), or an external
                |     population defined by the user. Please note that no user-defined population
                |     should bear the name of one of the default populations.

        :rtype: str
        """

        return self.swk_anthro.Population

    @population.setter
    def population(self, value: str):
        """
        :param str value:
        """

        self.swk_anthro.Population = value

    @property
    def population_accommodation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PopulationAccommodation() As double
                | 
                |     Returns or sets the population accommodation. The population accommodation
                |     is used in the multi-normal
                |     algorithm, to calculate the limits of the automatic
                |     variables
                |     when a user-defined anthropometry is entered.
                |     The greater the population accommodation is, the wider the
                |     limits
                |     on the automatic variables will be. The value of this property must le
                |     within the range [0.0, 100.0].

        :rtype: float
        """

        return self.swk_anthro.PopulationAccommodation

    @population_accommodation.setter
    def population_accommodation(self, value: float):
        """
        :param float value:
        """

        self.swk_anthro.PopulationAccommodation = value

    def get_variable_at_index(self, pi_index: int) -> SWKAnthroVariable:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVariableAtIndex(long piIndex) As SWKAnthroVariable
                | 
                |     Returns the variable at the specified index.
                | 
                |     Parameters:
                | 
                |         piIndex
                |             The index of the variable to retrieve.

        :param int pi_index:
        :rtype: SWKAnthroVariable
        """
        return SWKAnthroVariable(self.swk_anthro.GetVariableAtIndex(pi_index))

    def get_variable_from_us_number(self, pi_ref_number: int) -> SWKAnthroVariable:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVariableFromUsNumber(long piRefNumber) As
                | SWKAnthroVariable
                | 
                |     Returns the variable from a specified us number.
                | 
                |     Parameters:
                | 
                |         piRefNumber
                |             The reference number of the variable to retrieve (ex.: 3 for us3,
                |             100 for us100, etc).

        :param int pi_ref_number:
        :rtype: SWKAnthroVariable
        """
        return SWKAnthroVariable(self.swk_anthro.GetVariableFromUsNumber(pi_ref_number))

    def reset(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Reset()
                | 
                |     Reset the anthtropometry. This method resets each variable back to the
                |     automatic mode, and then updates the anthropometry.

        :rtype: None
        """
        return self.swk_anthro.Reset()

    def __repr__(self):
        return f'SWKAnthro(name="{self.name}")'
